==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-mainmenu/translations/mainmenu_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="102"/>
        <source>Search...</source>
        <translation>Hľadať...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="110"/>
        <source>Show/hide main menu</source>
        <translation>Zobraziť/skryť hlavné menu</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Nastavenia hlavného menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikonka:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Text tlačidla:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Vlastná veľkosť písma:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Súbor menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Súbor menu:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Max. šírka položiek:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Zobraziť zodpovedajúce položky:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Maximum viditeľných položiek:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrovať položky menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Pri vyhľadávaní skryť položky menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Po zobrazení menu vymazať históriu vyhľadávania</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Kliknite na tlačidlo pre uloženie:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>Vrátiť späť</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>Vybrať ikonu súboru</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>Obrázky (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>Vybrať súbor menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>Súbory menu (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-mainmenu/translations/mainmenu_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="106"/>
        <source>Search...</source>
        <translation>Hľadať...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="114"/>
        <source>Show/hide main menu</source>
        <translation>Zobraziť/skryť hlavné menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="496"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="504"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="505"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="511"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="512"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="518"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Nastavenia hlavného menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikonka:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Text tlačidla:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Vlastná veľkosť písma:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Súbor menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Súbor menu:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Max. šírka položiek:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Zobraziť zodpovedajúce položky:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Maximum viditeľných položiek:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrovať položky menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Pri vyhľadávaní skryť položky menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Po zobrazení menu vymazať históriu vyhľadávania</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Kliknite na tlačidlo pre uloženie:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="72"/>
        <source>Reset</source>
        <translation>Vrátiť späť</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="166"/>
        <source>Choose icon file</source>
        <translation>Vybrať ikonu súboru</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="168"/>
        <source>Images (*.svg *.png)</source>
        <translation>Obrázky (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="180"/>
        <source>Choose menu file</source>
        <translation>Vybrať súbor menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="182"/>
        <source>Menu files (*.menu)</source>
        <translation>Súbory menu (*.menu)</translation>
    </message>
</context>
</TS>
